@@ -1,21 +1,9 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2001, 2002 Ellis Whitehead <ellis@kde.org>
-    Copyright (C) 2007 Andreas Hartmetz <ahartmetz@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2001, 2002 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2007 Andreas Hartmetz <ahartmetz@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KKEYSEQUENCEWIDGET_H
@@ -46,51 +34,38 @@ class KActionCollection;
  *
  * @author Mark Donohoe <donohoe@kde.org>
  */
-class KXMLGUI_EXPORT KKeySequenceWidget: public QWidget
+class KXMLGUI_EXPORT KKeySequenceWidget : public QWidget
 {
     Q_OBJECT
 
     /// @since 5.65
-    Q_PROPERTY(
-        QKeySequence keySequence
-        READ keySequence
-        WRITE setKeySequence
-        NOTIFY keySequenceChanged)
+    Q_PROPERTY(QKeySequence keySequence READ keySequence WRITE setKeySequence NOTIFY keySequenceChanged)
 
-    Q_PROPERTY(
-        bool multiKeyShortcutsAllowed
-        READ multiKeyShortcutsAllowed
-        WRITE setMultiKeyShortcutsAllowed)
+    Q_PROPERTY(bool multiKeyShortcutsAllowed READ multiKeyShortcutsAllowed WRITE setMultiKeyShortcutsAllowed)
 
-    Q_PROPERTY(
-        ShortcutTypes checkForConflictsAgainst
-        READ checkForConflictsAgainst
-        WRITE setCheckForConflictsAgainst)
+    Q_PROPERTY(ShortcutTypes checkForConflictsAgainst READ checkForConflictsAgainst WRITE setCheckForConflictsAgainst)
 
-    Q_PROPERTY(
-        bool modifierlessAllowed
-        READ isModifierlessAllowed
-        WRITE setModifierlessAllowed)
+    Q_PROPERTY(bool modifierlessAllowed READ isModifierlessAllowed WRITE setModifierlessAllowed)
 
 public:
-    ///An enum about validation when setting a key sequence.
+    /// An enum about validation when setting a key sequence.
     ///@see setKeySequence()
     enum Validation {
-        ///Validate key sequence
+        /// Validate key sequence
         Validate = 0,
-        ///Use key sequence without validation
-        NoValidate = 1
+        /// Use key sequence without validation
+        NoValidate = 1,
     };
 
     /**
-    * Constructor.
-    */
+     * Constructor.
+     */
     explicit KKeySequenceWidget(QWidget *parent = nullptr);
 
     /**
-    * Destructs the widget.
-    */
-    virtual ~KKeySequenceWidget();
+     * Destructs the widget.
+     */
+    ~KKeySequenceWidget() override;
 
     /**
      * \name Configuration
@@ -101,10 +76,10 @@ public:
     //@{
 
     enum ShortcutType {
-        None           = 0x00,      //!< No checking for conflicts
-        LocalShortcuts = 0x01,      //!< Check with local shortcuts. @see setCheckActionCollections()
-        StandardShortcuts = 0x02,   //!< Check against standard shortcuts. @see KStandardShortcut
-        GlobalShortcuts = 0x04      //!< Check against global shortcuts. @see KGlobalAccel
+        None = 0x00, //!< No checking for conflicts
+        LocalShortcuts = 0x01, //!< Check with local shortcuts. @see setCheckActionCollections()
+        StandardShortcuts = 0x02, //!< Check against standard shortcuts. @see KStandardShortcut
+        GlobalShortcuts = 0x04, //!< Check against global shortcuts. @see KGlobalAccel
     };
     /**
      * Stores a combination of #ShortcutType values.
@@ -138,7 +113,7 @@ public:
      * of so make sure it doesn't inadvertly save some unwanted changes
      * too. Read its documentation for some limitation when handling
      * global shortcuts.
-    *
+     *
      * If you want to do the conflict checking yourself here are some code
      * snippets for global ...
      *
@@ -308,9 +283,6 @@ public Q_SLOTS:
      */
     void applyStealShortcut();
 
-private:
-    Q_PRIVATE_SLOT(d, void doneRecording())
-
 private:
     friend class KKeySequenceWidgetPrivate;
     KKeySequenceWidgetPrivate *const d;
@@ -320,4 +292,4 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KKeySequenceWidget::ShortcutTypes)
 
-#endif //KKEYSEQUENCEWIDGET_H
+#endif // KKEYSEQUENCEWIDGET_H
